/*
 * Copyright 2005, 2006 University of Leiden.
 *
 * This file is part of MIA+EWS.
 *
 * MIA+EWS is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * MIA+EWS is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with MIA; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
/*******************************************************************************
* E.S.O. - VLT project
*
* "@(#) $Id: DRfit.h,v 1.4 2002/05/08 21:24:47 jdejong Exp $"
*
* who       when      what
* --------  --------  ----------------------------------------------
* jdejong 2002-05-08  imported
*/

/************************************************************************
 *
 *----------------------------------------------------------------------
 */
/* $Id: DRfit.h,v 1.4 2002/05/08 21:24:47 jdejong Exp $ */

#ifndef _DRFIT_H
#define _DRFIT_H
/*----------------------------------------------------------------------- */
/* Routines and parameters for MIDI Delay-Rate fringe fitting             */
/*----------------------------------------------------------------------- */
#include <time.h>
#include <math.h>
#include <malloc.h>
#include <string.h>
#include <stdio.h>
#include <stdlib.h>
#include "imaging_detector.h"
#include "cal_table.h"
#include "image.h"
#include "history.h"

void setup_DRfringe_fit(char *pixfile, fitsfile *inputfptr,
			int nf, int nt, float time_incr, 
			imaging_detector_table_def* detector);
/*----------------------------------------------------------------------- */
/*   Setup for fit to spectrally dispersed interferometer data using      */
/*   a two dimensional Fourier transform.                                 */
/*   The delay-rate image is initialized if pixfile is non NULL           */
/*   Necessary structures are allocated.                                  */
/*   Inputs:                                                              */
/*      pixfile   name of output Delay-rate image, NULL=>don't write      */
/*      inputfptr cfitsio pointer to input FITS file                      */
/*                used for delay-rate image                               */
/*      nf        Number of frequency channels in spectrum                */
/*      nt        Number of times                                         */
/*      time_incr Time step between samples in sec                        */
/*      detector  imaging_detector table definition structure             */
/*----------------------------------------------------------------------- */

void DRfringe_fit_data (float **spectrum, float **big, 
		      int nf, int nt, float time_incr,
		      float *OPD_off, float *times, int narrow,
		      imaging_detector_table_def* detector,
		      cal_table_row *cal_row);
/*----------------------------------------------------------------------- */
/*   Fit spectrally dispersed interferometer data using                   */
/*   a two dimensional Fourier transform.                                 */
/*   Also writes delay-rate images to FITS cube if requested.             */
/*   Notes:                                                               */
/*    1) setup_DRfringe_fit must be called before first call to           */
/*       DRfringe_fit_data                                                */
/*    2) shutdown_DRfringe_fit should be called after last call to        */
/*       DRfringe_fit_data                                                */
/*                                                                        */
/*   Steps:                                                               */
/*     1) apply 2D notch filter to suppress non source signals            */
/*        Also zero pad array to big for better resolution                */
/*     2) remove instrumental OPD                                         */
/*     3) FFT in time direction                                           */
/*     4) FT in frequency direction                                       */
/*     5) Estimate location of the peak                                   */
/*   Inputs:                                                              */
/*      spectrum  Measured spectrum  (nf x nt) array of detector values   */
/*      big       Double size work array for zero padded fft              */
/*      nf        Number of frequency channels in spectrum                */
/*      nt        Number of times                                         */
/*      time_incr Time step between samples in sec                        */
/*      OPD_off   OPD offset applied (seconds) per sample                 */
/*      times     Times relative to reference time (sec)                  */
/*      narrow    if true (!=0) restrict the delay and rate windows       */
/*      detector  imaging_detector table definition structure             */
/*   Outputs:                                                             */
/*      cal_row   calibration table structure for result, ignore if NULL  */
/*----------------------------------------------------------------------- */

void shutdown_DRfringe_fit(int *ierr);
/*----------------------------------------------------------------------- */
/*   Shutdown fit to spectrally dispersed interferometer,                 */
/*   output delay-rate image is closed if written and all allocated       */ 
/*   structures are deleted.                                              */
/*   Outputs:                                                             */
/*      ierr        Error code: 0 => ok                                   */
/*----------------------------------------------------------------------- */

#endif /* end DRFIT_H */

/* */
